# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _batch_action: str
    _column_definitions: List[ColumnDefinitionOutputV1]
    _condition_monitor: Optional[ConditionMonitorOutputV1]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _exports: Optional[List[ExportPreviewV1]]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _item_finder: Optional[ItemFinderOutputV1]
    _name: str
    _navigation_column_id: Optional[str]
    _scoped_to: Optional[str]
    _status_message: Optional[str]
    _subscription: Optional[ItemPreviewV1]
    _table_type: str
    _translation_key: Optional[str]
    _type: str
    _unique_id_column_name: Optional[str]
    _vantage: Optional[ItemPreviewV1]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        batch_action: Optional[str] = None,
        column_definitions: Optional[List[ColumnDefinitionOutputV1]] = None,
        condition_monitor: Optional[ConditionMonitorOutputV1] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        exports: Optional[List[ExportPreviewV1]] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        item_finder: Optional[ItemFinderOutputV1] = None,
        name: Optional[str] = None,
        navigation_column_id: Optional[str] = None,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        subscription: Optional[ItemPreviewV1] = None,
        table_type: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        unique_id_column_name: Optional[str] = None,
        vantage: Optional[ItemPreviewV1] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def batch_action(self) -> str: ...

    @batch_action.setter
    def batch_action(self, batch_action: str) -> None: ...

    @property
    def column_definitions(self) -> List[ColumnDefinitionOutputV1]: ...

    @column_definitions.setter
    def column_definitions(self, column_definitions: List[ColumnDefinitionOutputV1]) -> None: ...

    @property
    def condition_monitor(self) -> Optional[ConditionMonitorOutputV1]: ...

    @condition_monitor.setter
    def condition_monitor(self, condition_monitor: Optional[ConditionMonitorOutputV1]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def exports(self) -> Optional[List[ExportPreviewV1]]: ...

    @exports.setter
    def exports(self, exports: Optional[List[ExportPreviewV1]]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def item_finder(self) -> Optional[ItemFinderOutputV1]: ...

    @item_finder.setter
    def item_finder(self, item_finder: Optional[ItemFinderOutputV1]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def navigation_column_id(self) -> Optional[str]: ...

    @navigation_column_id.setter
    def navigation_column_id(self, navigation_column_id: Optional[str]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def subscription(self) -> Optional[ItemPreviewV1]: ...

    @subscription.setter
    def subscription(self, subscription: Optional[ItemPreviewV1]) -> None: ...

    @property
    def table_type(self) -> str: ...

    @table_type.setter
    def table_type(self, table_type: str) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def unique_id_column_name(self) -> Optional[str]: ...

    @unique_id_column_name.setter
    def unique_id_column_name(self, unique_id_column_name: Optional[str]) -> None: ...

    @property
    def vantage(self) -> Optional[ItemPreviewV1]: ...

    @vantage.setter
    def vantage(self, vantage: Optional[ItemPreviewV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ListConfigFieldV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'element_config_field': 'ConfigFieldV1',
        'element_type': 'str',
        'max_item_count': 'int',
        'min_item_count': 'int'
    }

    attribute_map = {
        'element_config_field': 'elementConfigField',
        'element_type': 'elementType',
        'max_item_count': 'maxItemCount',
        'min_item_count': 'minItemCount'
    }

    def __init__(self, element_config_field=None, element_type=None, max_item_count=None, min_item_count=None):
        """
        ListConfigFieldV1 - a model defined in Swagger
        """

        self._element_config_field = None
        self._element_type = None
        self._max_item_count = None
        self._min_item_count = None

        if element_config_field is not None:
          self.element_config_field = element_config_field
        if element_type is not None:
          self.element_type = element_type
        if max_item_count is not None:
          self.max_item_count = max_item_count
        if min_item_count is not None:
          self.min_item_count = min_item_count

    @property
    def element_config_field(self):
        """
        Gets the element_config_field of this ListConfigFieldV1.

        :return: The element_config_field of this ListConfigFieldV1.
        :rtype: ConfigFieldV1
        """
        return self._element_config_field

    @element_config_field.setter
    def element_config_field(self, element_config_field):
        """
        Sets the element_config_field of this ListConfigFieldV1.

        :param element_config_field: The element_config_field of this ListConfigFieldV1.
        :type: ConfigFieldV1
        """

        self._element_config_field = element_config_field

    @property
    def element_type(self):
        """
        Gets the element_type of this ListConfigFieldV1.
        The type of elements in the list

        :return: The element_type of this ListConfigFieldV1.
        :rtype: str
        """
        return self._element_type

    @element_type.setter
    def element_type(self, element_type):
        """
        Sets the element_type of this ListConfigFieldV1.
        The type of elements in the list

        :param element_type: The element_type of this ListConfigFieldV1.
        :type: str
        """

        self._element_type = element_type

    @property
    def max_item_count(self):
        """
        Gets the max_item_count of this ListConfigFieldV1.
        The maximum number of items in the list

        :return: The max_item_count of this ListConfigFieldV1.
        :rtype: int
        """
        return self._max_item_count

    @max_item_count.setter
    def max_item_count(self, max_item_count):
        """
        Sets the max_item_count of this ListConfigFieldV1.
        The maximum number of items in the list

        :param max_item_count: The max_item_count of this ListConfigFieldV1.
        :type: int
        """

        self._max_item_count = max_item_count

    @property
    def min_item_count(self):
        """
        Gets the min_item_count of this ListConfigFieldV1.
        The minimum number of items in the list

        :return: The min_item_count of this ListConfigFieldV1.
        :rtype: int
        """
        return self._min_item_count

    @min_item_count.setter
    def min_item_count(self, min_item_count):
        """
        Sets the min_item_count of this ListConfigFieldV1.
        The minimum number of items in the list

        :param min_item_count: The min_item_count of this ListConfigFieldV1.
        :type: int
        """

        self._min_item_count = min_item_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ListConfigFieldV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class SystemApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_add_on_tool(
        self,
        **kwargs: Any,
    ) -> AddOnToolOutputV1: ...

    def create_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_add_on_tool(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def disable_licensed_feature(
        self,
        **kwargs: Any,
    ) -> None: ...

    def disable_licensed_feature_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def enable_licensed_feature(
        self,
        **kwargs: Any,
    ) -> None: ...

    def enable_licensed_feature_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_add_on_tool(
        self,
        **kwargs: Any,
    ) -> AddOnToolOutputV1: ...

    def get_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_add_on_tools(
        self,
        **kwargs: Any,
    ) -> GetAddOnToolsOutputV1: ...

    def get_add_on_tools_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_administrator_contact_information(
        self,
        **kwargs: Any,
    ) -> AdministratorContactInformationV1: ...

    def get_administrator_contact_information_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_agent_key(
        self,
        **kwargs: Any,
    ) -> AgentKeyOutputV1: ...

    def get_agent_key_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_build_info(
        self,
        **kwargs: Any,
    ) -> ServerBuildInfoOutputV1: ...

    def get_build_info_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_configuration_options(
        self,
        **kwargs: Any,
    ) -> ConfigurationOutputV1: ...

    def get_configuration_options_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_installer_file(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_installer_file_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_license(
        self,
        **kwargs: Any,
    ) -> LicenseStatusOutputV1: ...

    def get_license_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_open_ping(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def get_open_ping_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_ping(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def get_ping_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_release_notes(
        self,
        **kwargs: Any,
    ) -> ReleaseNotesOutputV1: ...

    def get_release_notes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_sent_emails(
        self,
        **kwargs: Any,
    ) -> SentEmailsListOutputV1: ...

    def get_sent_emails_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_server_load(
        self,
        **kwargs: Any,
    ) -> ServerLoadOutputV1: ...

    def get_server_load_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_server_status(
        self,
        **kwargs: Any,
    ) -> ServerStatusOutputV1: ...

    def get_server_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_supported_units(
        self,
        **kwargs: Any,
    ) -> SupportedUnitsOutputV1: ...

    def get_supported_units_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_thread_state(
        self,
        **kwargs: Any,
    ) -> str: ...

    def get_thread_state_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_license(
        self,
        **kwargs: Any,
    ) -> LicenseImporterOutputV1: ...

    def import_license_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_administrator_contact_information(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def set_administrator_contact_information_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_configuration_options(
        self,
        **kwargs: Any,
    ) -> ConfigurationOutputV1: ...

    def set_configuration_options_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def u_o_ms(
        self,
        **kwargs: Any,
    ) -> UnitsOfMeasureOutputV1: ...

    def u_o_ms_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_add_on_tool(
        self,
        **kwargs: Any,
    ) -> AddOnToolOutputV1: ...

    def update_add_on_tool_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FolderSearchResultsV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _estimated_total_hits: int
    _facet_distribution: Dict[str, Any]
    _hits: List[Dict[str, Any]]
    _hits_per_page: int
    _page: int
    _path: Optional[List[ItemPreviewV1]]


    def __init__(
        self,
        estimated_total_hits: Optional[int] = None,
        facet_distribution: Optional[Dict[str, Any]] = None,
        hits: Optional[List[Dict[str, Any]]] = None,
        hits_per_page: Optional[int] = None,
        page: Optional[int] = None,
        path: Optional[List[ItemPreviewV1]] = None,
    ) -> None: ...

    @property
    def estimated_total_hits(self) -> int: ...

    @estimated_total_hits.setter
    def estimated_total_hits(self, estimated_total_hits: int) -> None: ...

    @property
    def facet_distribution(self) -> Dict[str, Any]: ...

    @facet_distribution.setter
    def facet_distribution(self, facet_distribution: Dict[str, Any]) -> None: ...

    @property
    def hits(self) -> List[Dict[str, Any]]: ...

    @hits.setter
    def hits(self, hits: List[Dict[str, Any]]) -> None: ...

    @property
    def hits_per_page(self) -> int: ...

    @hits_per_page.setter
    def hits_per_page(self, hits_per_page: int) -> None: ...

    @property
    def page(self) -> int: ...

    @page.setter
    def page(self, page: int) -> None: ...

    @property
    def path(self) -> Optional[List[ItemPreviewV1]]: ...

    @path.setter
    def path(self, path: Optional[List[ItemPreviewV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourceStatisticsV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _median_datasource_nanos: Optional[int]
    _median_queue_nanos: Optional[int]
    _median_total_nanos: Optional[int]
    _most_recent_cancellation: Optional[str]
    _most_recent_failure: Optional[str]
    _most_recent_success: Optional[str]
    _most_recent_timeout: Optional[str]
    _num_cancellations: Optional[int]
    _num_failures: Optional[int]
    _num_successes: Optional[int]
    _num_timeouts: Optional[int]
    _total_num_datums: Optional[int]


    def __init__(
        self,
        median_datasource_nanos: Optional[int] = None,
        median_queue_nanos: Optional[int] = None,
        median_total_nanos: Optional[int] = None,
        most_recent_cancellation: Optional[str] = None,
        most_recent_failure: Optional[str] = None,
        most_recent_success: Optional[str] = None,
        most_recent_timeout: Optional[str] = None,
        num_cancellations: Optional[int] = None,
        num_failures: Optional[int] = None,
        num_successes: Optional[int] = None,
        num_timeouts: Optional[int] = None,
        total_num_datums: Optional[int] = None,
    ) -> None: ...

    @property
    def median_datasource_nanos(self) -> Optional[int]: ...

    @median_datasource_nanos.setter
    def median_datasource_nanos(self, median_datasource_nanos: Optional[int]) -> None: ...

    @property
    def median_queue_nanos(self) -> Optional[int]: ...

    @median_queue_nanos.setter
    def median_queue_nanos(self, median_queue_nanos: Optional[int]) -> None: ...

    @property
    def median_total_nanos(self) -> Optional[int]: ...

    @median_total_nanos.setter
    def median_total_nanos(self, median_total_nanos: Optional[int]) -> None: ...

    @property
    def most_recent_cancellation(self) -> Optional[str]: ...

    @most_recent_cancellation.setter
    def most_recent_cancellation(self, most_recent_cancellation: Optional[str]) -> None: ...

    @property
    def most_recent_failure(self) -> Optional[str]: ...

    @most_recent_failure.setter
    def most_recent_failure(self, most_recent_failure: Optional[str]) -> None: ...

    @property
    def most_recent_success(self) -> Optional[str]: ...

    @most_recent_success.setter
    def most_recent_success(self, most_recent_success: Optional[str]) -> None: ...

    @property
    def most_recent_timeout(self) -> Optional[str]: ...

    @most_recent_timeout.setter
    def most_recent_timeout(self, most_recent_timeout: Optional[str]) -> None: ...

    @property
    def num_cancellations(self) -> Optional[int]: ...

    @num_cancellations.setter
    def num_cancellations(self, num_cancellations: Optional[int]) -> None: ...

    @property
    def num_failures(self) -> Optional[int]: ...

    @num_failures.setter
    def num_failures(self, num_failures: Optional[int]) -> None: ...

    @property
    def num_successes(self) -> Optional[int]: ...

    @num_successes.setter
    def num_successes(self, num_successes: Optional[int]) -> None: ...

    @property
    def num_timeouts(self) -> Optional[int]: ...

    @num_timeouts.setter
    def num_timeouts(self, num_timeouts: Optional[int]) -> None: ...

    @property
    def total_num_datums(self) -> Optional[int]: ...

    @total_num_datums.setter
    def total_num_datums(self, total_num_datums: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class AgentsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_agent(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_connection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_connector(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def configured_directives(
        self,
        **kwargs: Any,
    ) -> ConfiguredDirectivesOutputV1: ...

    def configured_directives_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_or_update_agent(
        self,
        **kwargs: Any,
    ) -> AgentOutputV1: ...

    def create_or_update_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_or_update_connection(
        self,
        **kwargs: Any,
    ) -> ConnectionOutputV1: ...

    def create_or_update_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_or_update_connector(
        self,
        **kwargs: Any,
    ) -> ConnectorOutputV1: ...

    def create_or_update_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_secret_for_connection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_secret_for_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_agent(
        self,
        **kwargs: Any,
    ) -> AgentOutputV1: ...

    def get_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_agent_status(
        self,
        **kwargs: Any,
    ) -> List[AgentStatusV1]: ...

    def get_agent_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connection(
        self,
        **kwargs: Any,
    ) -> ConnectionOutputV1: ...

    def get_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connections(
        self,
        **kwargs: Any,
    ) -> ConnectionsOutputV1: ...

    def get_connections_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connector(
        self,
        **kwargs: Any,
    ) -> ConnectorOutputV1: ...

    def get_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_connectors(
        self,
        **kwargs: Any,
    ) -> ConnectorsOutputV1: ...

    def get_connectors_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_datasources_status(
        self,
        **kwargs: Any,
    ) -> DatasourcesStatusOutputV1: ...

    def get_datasources_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_remote_update_directives(
        self,
        **kwargs: Any,
    ) -> RemoteAgentDirectivesOutputV1: ...

    def get_remote_update_directives_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def index(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def index_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def post_agent_status(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def post_agent_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def pre_provision(
        self,
        **kwargs: Any,
    ) -> PreProvisionOutputV1: ...

    def pre_provision_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def provision(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def provision_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def restart_agent(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def restart_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def restart_connector(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def restart_connector_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def store_secret_for_connection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def store_secret_for_connection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_directive(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def update_directive_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_remote_agent_status(
        self,
        **kwargs: Any,
    ) -> RemoteAgentStatusOutputV1: ...

    def update_remote_agent_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AgentStatusV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _connections: List[ConnectionStatusV1]
    _datasource_access_stats: Optional[List[DatasourceAccessStatsV1]]
    _id: str
    _name: str
    _remote_agent: Optional[bool]
    _status: str
    _version: Optional[str]


    def __init__(
        self,
        connections: Optional[List[ConnectionStatusV1]] = None,
        datasource_access_stats: Optional[List[DatasourceAccessStatsV1]] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        remote_agent: Optional[bool] = False,
        status: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def connections(self) -> List[ConnectionStatusV1]: ...

    @connections.setter
    def connections(self, connections: List[ConnectionStatusV1]) -> None: ...

    @property
    def datasource_access_stats(self) -> Optional[List[DatasourceAccessStatsV1]]: ...

    @datasource_access_stats.setter
    def datasource_access_stats(self, datasource_access_stats: Optional[List[DatasourceAccessStatsV1]]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def remote_agent(self) -> Optional[bool]: ...

    @remote_agent.setter
    def remote_agent(self, remote_agent: Optional[bool]) -> None: ...

    @property
    def status(self) -> str: ...

    @status.setter
    def status(self, status: str) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConditionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _capsule_id_property: Optional[str]
    _capsule_properties: Optional[List[CapsulePropertyOutputV1]]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _formula: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _maximum_duration: Optional[str]
    _name: str
    _package_name: Optional[str]
    _parameters: Optional[List[FormulaParameterOutputV1]]
    _permissions_from_datasource: Optional[bool]
    _scoped_to: Optional[str]
    _security_string: Optional[str]
    _source_condition: Optional[str]
    _source_security_string: Optional[str]
    _status_message: Optional[str]
    _storage_location: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _unit_of_measure: Optional[str]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        capsule_id_property: Optional[str] = None,
        capsule_properties: Optional[List[CapsulePropertyOutputV1]] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        formula: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        maximum_duration: Optional[str] = None,
        name: Optional[str] = None,
        package_name: Optional[str] = None,
        parameters: Optional[List[FormulaParameterOutputV1]] = None,
        permissions_from_datasource: Optional[bool] = False,
        scoped_to: Optional[str] = None,
        security_string: Optional[str] = None,
        source_condition: Optional[str] = None,
        source_security_string: Optional[str] = None,
        status_message: Optional[str] = None,
        storage_location: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        unit_of_measure: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def capsule_id_property(self) -> Optional[str]: ...

    @capsule_id_property.setter
    def capsule_id_property(self, capsule_id_property: Optional[str]) -> None: ...

    @property
    def capsule_properties(self) -> Optional[List[CapsulePropertyOutputV1]]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: Optional[List[CapsulePropertyOutputV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def formula(self) -> Optional[str]: ...

    @formula.setter
    def formula(self, formula: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def maximum_duration(self) -> Optional[str]: ...

    @maximum_duration.setter
    def maximum_duration(self, maximum_duration: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def package_name(self) -> Optional[str]: ...

    @package_name.setter
    def package_name(self, package_name: Optional[str]) -> None: ...

    @property
    def parameters(self) -> Optional[List[FormulaParameterOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[FormulaParameterOutputV1]]) -> None: ...

    @property
    def permissions_from_datasource(self) -> Optional[bool]: ...

    @permissions_from_datasource.setter
    def permissions_from_datasource(self, permissions_from_datasource: Optional[bool]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def security_string(self) -> Optional[str]: ...

    @security_string.setter
    def security_string(self, security_string: Optional[str]) -> None: ...

    @property
    def source_condition(self) -> Optional[str]: ...

    @source_condition.setter
    def source_condition(self, source_condition: Optional[str]) -> None: ...

    @property
    def source_security_string(self) -> Optional[str]: ...

    @source_security_string.setter
    def source_security_string(self, source_security_string: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def storage_location(self) -> Optional[str]: ...

    @storage_location.setter
    def storage_location(self, storage_location: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def unit_of_measure(self) -> Optional[str]: ...

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class StoredTableColumnInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_name: str
    _column_type: str
    _column_uom: Optional[str]
    _description: Optional[str]
    _is_hidden: Optional[bool]
    _is_indexed: Optional[bool]
    _sort_ascending: Optional[bool]
    _sort_index: Optional[int]


    def __init__(
        self,
        column_name: Optional[str] = None,
        column_type: Optional[str] = None,
        column_uom: Optional[str] = None,
        description: Optional[str] = None,
        is_hidden: Optional[bool] = None,
        is_indexed: Optional[bool] = None,
        sort_ascending: Optional[bool] = None,
        sort_index: Optional[int] = None,
    ) -> None: ...

    @property
    def column_name(self) -> str: ...

    @column_name.setter
    def column_name(self, column_name: str) -> None: ...

    @property
    def column_type(self) -> str: ...

    @column_type.setter
    def column_type(self, column_type: str) -> None: ...

    @property
    def column_uom(self) -> Optional[str]: ...

    @column_uom.setter
    def column_uom(self, column_uom: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def is_hidden(self) -> Optional[bool]: ...

    @is_hidden.setter
    def is_hidden(self, is_hidden: Optional[bool]) -> None: ...

    @property
    def is_indexed(self) -> Optional[bool]: ...

    @is_indexed.setter
    def is_indexed(self, is_indexed: Optional[bool]) -> None: ...

    @property
    def sort_ascending(self) -> Optional[bool]: ...

    @sort_ascending.setter
    def sort_ascending(self, sort_ascending: Optional[bool]) -> None: ...

    @property
    def sort_index(self) -> Optional[int]: ...

    @sort_index.setter
    def sort_index(self, sort_index: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RadialGaugeRehydrationInstructionsInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max': 'object',
        'series_identifier': 'str',
        'series_name': 'str',
        'time_key': 'str',
        'value_key': 'str'
    }

    attribute_map = {
        'max': 'max',
        'series_identifier': 'seriesIdentifier',
        'series_name': 'seriesName',
        'time_key': 'timeKey',
        'value_key': 'valueKey'
    }

    def __init__(self, max=None, series_identifier=None, series_name=None, time_key=None, value_key=None):
        """
        RadialGaugeRehydrationInstructionsInputV1 - a model defined in Swagger
        """

        self._max = None
        self._series_identifier = None
        self._series_name = None
        self._time_key = None
        self._value_key = None

        if max is not None:
          self.max = max
        if series_identifier is not None:
          self.series_identifier = series_identifier
        if series_name is not None:
          self.series_name = series_name
        if time_key is not None:
          self.time_key = time_key
        if value_key is not None:
          self.value_key = value_key

    @property
    def max(self):
        """
        Gets the max of this RadialGaugeRehydrationInstructionsInputV1.
        Optional max value or column key to use for the gauge

        :return: The max of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: object
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this RadialGaugeRehydrationInstructionsInputV1.
        Optional max value or column key to use for the gauge

        :param max: The max of this RadialGaugeRehydrationInstructionsInputV1.
        :type: object
        """

        self._max = max

    @property
    def series_identifier(self):
        """
        Gets the series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        Identifier that maps radial gauge data to chart options

        :return: The series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._series_identifier

    @series_identifier.setter
    def series_identifier(self, series_identifier):
        """
        Sets the series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        Identifier that maps radial gauge data to chart options

        :param series_identifier: The series_identifier of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """

        self._series_identifier = series_identifier

    @property
    def series_name(self):
        """
        Gets the series_name of this RadialGaugeRehydrationInstructionsInputV1.
        Display name to associate with the hydrated series values

        :return: The series_name of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._series_name

    @series_name.setter
    def series_name(self, series_name):
        """
        Sets the series_name of this RadialGaugeRehydrationInstructionsInputV1.
        Display name to associate with the hydrated series values

        :param series_name: The series_name of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """

        self._series_name = series_name

    @property
    def time_key(self):
        """
        Gets the time_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the time key for radial gauge rehydration

        :return: The time_key of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._time_key

    @time_key.setter
    def time_key(self, time_key):
        """
        Sets the time_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the time key for radial gauge rehydration

        :param time_key: The time_key of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """
        if time_key is None:
            raise ValueError("Invalid value for `time_key`, must not be `None`")

        self._time_key = time_key

    @property
    def value_key(self):
        """
        Gets the value_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the value key for radial gauge rehydration

        :return: The value_key of this RadialGaugeRehydrationInstructionsInputV1.
        :rtype: str
        """
        return self._value_key

    @value_key.setter
    def value_key(self, value_key):
        """
        Sets the value_key of this RadialGaugeRehydrationInstructionsInputV1.
        The data column used as the value key for radial gauge rehydration

        :param value_key: The value_key of this RadialGaugeRehydrationInstructionsInputV1.
        :type: str
        """
        if value_key is None:
            raise ValueError("Invalid value for `value_key`, must not be `None`")

        self._value_key = value_key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RadialGaugeRehydrationInstructionsInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CalculatedTableInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _group_by: Optional[List[str]]
    _join: Optional[JoinInputV1]
    _name: str
    _order_by: Optional[List[OrderByInputV1]]
    _select_expressions: List[CalculatedTableColumnInputV1]
    _source: str


    def __init__(
        self,
        description: Optional[str] = None,
        group_by: Optional[List[str]] = None,
        join: Optional[JoinInputV1] = None,
        name: Optional[str] = None,
        order_by: Optional[List[OrderByInputV1]] = None,
        select_expressions: Optional[List[CalculatedTableColumnInputV1]] = None,
        source: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def group_by(self) -> Optional[List[str]]: ...

    @group_by.setter
    def group_by(self, group_by: Optional[List[str]]) -> None: ...

    @property
    def join(self) -> Optional[JoinInputV1]: ...

    @join.setter
    def join(self, join: Optional[JoinInputV1]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def order_by(self) -> Optional[List[OrderByInputV1]]: ...

    @order_by.setter
    def order_by(self, order_by: Optional[List[OrderByInputV1]]) -> None: ...

    @property
    def select_expressions(self) -> List[CalculatedTableColumnInputV1]: ...

    @select_expressions.setter
    def select_expressions(self, select_expressions: List[CalculatedTableColumnInputV1]) -> None: ...

    @property
    def source(self) -> str: ...

    @source.setter
    def source(self, source: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _access_key_validity_duration: Optional[int]
    _agent_provisioning_at: Optional[str]
    _agent_provisioning_source_address: Optional[str]
    _agent_provisioning_status: Optional[str]
    _capabilities: Optional[List[str]]
    _capability_grants: Optional[List[CapabilityInheritanceOutputV1]]
    _created_at: Optional[str]
    _datasource_name: Optional[str]
    _description: Optional[str]
    _effective_access_key_validity_duration: Optional[ScalarValueOutputV1]
    _effective_permissions: Optional[PermissionsV1]
    _effective_session_duration: Optional[ScalarValueOutputV1]
    _email: Optional[str]
    _first_name: Optional[str]
    _groups: Optional[List[IdentityPreviewV1]]
    _id: str
    _is_active: Optional[bool]
    _is_admin: Optional[bool]
    _is_archived: Optional[bool]
    _is_enabled: Optional[bool]
    _is_manager: Optional[bool]
    _is_password_settable: Optional[bool]
    _is_redacted: Optional[bool]
    _is_trusted: Optional[bool]
    _last_login_at: Optional[str]
    _last_name: Optional[str]
    _last_password_changed_at: Optional[str]
    _manager: Optional[IdentityPreviewV1]
    _max_requests: Optional[int]
    _name: str
    _password_expiry_status: Optional[str]
    _require_password_reset_on_next_login: Optional[bool]
    _role: Optional[str]
    _session_duration: Optional[int]
    _site: Optional[str]
    _status_message: Optional[str]
    _template_workstep_id: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _username: Optional[str]
    _workbench: Optional[str]


    def __init__(
        self,
        access_key_validity_duration: Optional[int] = None,
        agent_provisioning_at: Optional[str] = None,
        agent_provisioning_source_address: Optional[str] = None,
        agent_provisioning_status: Optional[str] = None,
        capabilities: Optional[List[str]] = None,
        capability_grants: Optional[List[CapabilityInheritanceOutputV1]] = None,
        created_at: Optional[str] = None,
        datasource_name: Optional[str] = None,
        description: Optional[str] = None,
        effective_access_key_validity_duration: Optional[ScalarValueOutputV1] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        effective_session_duration: Optional[ScalarValueOutputV1] = None,
        email: Optional[str] = None,
        first_name: Optional[str] = None,
        groups: Optional[List[IdentityPreviewV1]] = None,
        id: Optional[str] = None,
        is_active: Optional[bool] = False,
        is_admin: Optional[bool] = None,
        is_archived: Optional[bool] = False,
        is_enabled: Optional[bool] = False,
        is_manager: Optional[bool] = None,
        is_password_settable: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        is_trusted: Optional[bool] = None,
        last_login_at: Optional[str] = None,
        last_name: Optional[str] = None,
        last_password_changed_at: Optional[str] = None,
        manager: Optional[IdentityPreviewV1] = None,
        max_requests: Optional[int] = None,
        name: Optional[str] = None,
        password_expiry_status: Optional[str] = None,
        require_password_reset_on_next_login: Optional[bool] = None,
        role: Optional[str] = None,
        session_duration: Optional[int] = None,
        site: Optional[str] = None,
        status_message: Optional[str] = None,
        template_workstep_id: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        username: Optional[str] = None,
        workbench: Optional[str] = None,
    ) -> None: ...

    @property
    def access_key_validity_duration(self) -> Optional[int]: ...

    @access_key_validity_duration.setter
    def access_key_validity_duration(self, access_key_validity_duration: Optional[int]) -> None: ...

    @property
    def agent_provisioning_at(self) -> Optional[str]: ...

    @agent_provisioning_at.setter
    def agent_provisioning_at(self, agent_provisioning_at: Optional[str]) -> None: ...

    @property
    def agent_provisioning_source_address(self) -> Optional[str]: ...

    @agent_provisioning_source_address.setter
    def agent_provisioning_source_address(self, agent_provisioning_source_address: Optional[str]) -> None: ...

    @property
    def agent_provisioning_status(self) -> Optional[str]: ...

    @agent_provisioning_status.setter
    def agent_provisioning_status(self, agent_provisioning_status: Optional[str]) -> None: ...

    @property
    def capabilities(self) -> Optional[List[str]]: ...

    @capabilities.setter
    def capabilities(self, capabilities: Optional[List[str]]) -> None: ...

    @property
    def capability_grants(self) -> Optional[List[CapabilityInheritanceOutputV1]]: ...

    @capability_grants.setter
    def capability_grants(self, capability_grants: Optional[List[CapabilityInheritanceOutputV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def datasource_name(self) -> Optional[str]: ...

    @datasource_name.setter
    def datasource_name(self, datasource_name: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_access_key_validity_duration(self) -> Optional[ScalarValueOutputV1]: ...

    @effective_access_key_validity_duration.setter
    def effective_access_key_validity_duration(self, effective_access_key_validity_duration: Optional[ScalarValueOutputV1]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def effective_session_duration(self) -> Optional[ScalarValueOutputV1]: ...

    @effective_session_duration.setter
    def effective_session_duration(self, effective_session_duration: Optional[ScalarValueOutputV1]) -> None: ...

    @property
    def email(self) -> Optional[str]: ...

    @email.setter
    def email(self, email: Optional[str]) -> None: ...

    @property
    def first_name(self) -> Optional[str]: ...

    @first_name.setter
    def first_name(self, first_name: Optional[str]) -> None: ...

    @property
    def groups(self) -> Optional[List[IdentityPreviewV1]]: ...

    @groups.setter
    def groups(self, groups: Optional[List[IdentityPreviewV1]]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_active(self) -> Optional[bool]: ...

    @is_active.setter
    def is_active(self, is_active: Optional[bool]) -> None: ...

    @property
    def is_admin(self) -> Optional[bool]: ...

    @is_admin.setter
    def is_admin(self, is_admin: Optional[bool]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def is_manager(self) -> Optional[bool]: ...

    @is_manager.setter
    def is_manager(self, is_manager: Optional[bool]) -> None: ...

    @property
    def is_password_settable(self) -> Optional[bool]: ...

    @is_password_settable.setter
    def is_password_settable(self, is_password_settable: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def is_trusted(self) -> Optional[bool]: ...

    @is_trusted.setter
    def is_trusted(self, is_trusted: Optional[bool]) -> None: ...

    @property
    def last_login_at(self) -> Optional[str]: ...

    @last_login_at.setter
    def last_login_at(self, last_login_at: Optional[str]) -> None: ...

    @property
    def last_name(self) -> Optional[str]: ...

    @last_name.setter
    def last_name(self, last_name: Optional[str]) -> None: ...

    @property
    def last_password_changed_at(self) -> Optional[str]: ...

    @last_password_changed_at.setter
    def last_password_changed_at(self, last_password_changed_at: Optional[str]) -> None: ...

    @property
    def manager(self) -> Optional[IdentityPreviewV1]: ...

    @manager.setter
    def manager(self, manager: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def max_requests(self) -> Optional[int]: ...

    @max_requests.setter
    def max_requests(self, max_requests: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def password_expiry_status(self) -> Optional[str]: ...

    @password_expiry_status.setter
    def password_expiry_status(self, password_expiry_status: Optional[str]) -> None: ...

    @property
    def require_password_reset_on_next_login(self) -> Optional[bool]: ...

    @require_password_reset_on_next_login.setter
    def require_password_reset_on_next_login(self, require_password_reset_on_next_login: Optional[bool]) -> None: ...

    @property
    def role(self) -> Optional[str]: ...

    @role.setter
    def role(self, role: Optional[str]) -> None: ...

    @property
    def session_duration(self) -> Optional[int]: ...

    @session_duration.setter
    def session_duration(self, session_duration: Optional[int]) -> None: ...

    @property
    def site(self) -> Optional[str]: ...

    @site.setter
    def site(self, site: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def template_workstep_id(self) -> Optional[str]: ...

    @template_workstep_id.setter
    def template_workstep_id(self, template_workstep_id: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def username(self) -> Optional[str]: ...

    @username.setter
    def username(self, username: Optional[str]) -> None: ...

    @property
    def workbench(self) -> Optional[str]: ...

    @workbench.setter
    def workbench(self, workbench: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class SignalMonitorsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_signal_monitor(self, **kwargs):
        """
        Archive a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_signal_monitor(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the signal monitor to archive. (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_signal_monitor_with_http_info(**kwargs)
        else:
            (data) = self.archive_signal_monitor_with_http_info(**kwargs)
            return data

    def archive_signal_monitor_with_http_info(self, **kwargs):
        """
        Archive a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_signal_monitor_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the signal monitor to archive. (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_signal_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_signal_monitor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ArchiveOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_signal_monitor(self, **kwargs):
        """
        Create a new signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_signal_monitor(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SignalMonitorInputV1 body: (required)
        :return: SignalMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_signal_monitor_with_http_info(**kwargs)
        else:
            (data) = self.create_signal_monitor_with_http_info(**kwargs)
            return data

    def create_signal_monitor_with_http_info(self, **kwargs):
        """
        Create a new signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_signal_monitor_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SignalMonitorInputV1 body: (required)
        :return: SignalMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_signal_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_signal_monitor`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'SignalMonitorOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_monitored_signals(self, **kwargs):
        """
        Get a list of monitored signals for a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_monitored_signals(signal_monitor_id=signal_monitor_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str signal_monitor_id: (required)
        :return: MonitoredSignalOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MonitoredSignalOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_monitored_signals_with_http_info(**kwargs)
        else:
            (data) = self.get_monitored_signals_with_http_info(**kwargs)
            return data

    def get_monitored_signals_with_http_info(self, **kwargs):
        """
        Get a list of monitored signals for a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_monitored_signals_with_http_info(signal_monitor_id=signal_monitor_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str signal_monitor_id: (required)
        :return: MonitoredSignalOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MonitoredSignalOutputListV1
        """

        all_params = ['signal_monitor_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitored_signals" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'signal_monitor_id' is set
        if ('signal_monitor_id' not in params) or (params['signal_monitor_id'] is None):
            raise ValueError("Missing the required parameter `signal_monitor_id` when calling `get_monitored_signals`")


        collection_formats = {}

        path_params = {}
        if 'signal_monitor_id' in params:
            path_params['signalMonitorId'] = params['signal_monitor_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors/{signalMonitorId}/signals', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'MonitoredSignalOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_signal_monitor(self, **kwargs):
        """
        Get a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_signal_monitor(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the signal monitor (required)
        :return: SignalMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_signal_monitor_with_http_info(**kwargs)
        else:
            (data) = self.get_signal_monitor_with_http_info(**kwargs)
            return data

    def get_signal_monitor_with_http_info(self, **kwargs):
        """
        Get a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_signal_monitor_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the signal monitor (required)
        :return: SignalMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_signal_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_signal_monitor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'SignalMonitorOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_signal_monitor_metadata_list(self, **kwargs):
        """
        Get a list of metadata associated with signal monitors, including various properties that define their current state and behavior
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_signal_monitor_metadata_list(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] creator_ids: Filter items to only those created by the specified user IDs
        :param str name_search: Filter the items to those whose name match any part of the specified string
        :param str workbook_search: Filter the items to those whose signals are scoped to workbooks that match any part of the specified string
        :param list[str] signal_ids: Filter items to only those that are monitoring one of the specified signals as specified by the list of IDs
        :param bool enabled_filter: Filter items by their enabled status
        :param str workbook_type_filter: Filter items by the type of workbook they are scoped to
        :param int offset: The pagination offset, the number of items that will be skipped.
        :param int limit: The pagination limit, the total number of items that will be returned in this page of results
        :param str sort_by: Order the items by either name, workbook or createdAt
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: SignalMonitorMetadataOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorMetadataOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_signal_monitor_metadata_list_with_http_info(**kwargs)
        else:
            (data) = self.get_signal_monitor_metadata_list_with_http_info(**kwargs)
            return data

    def get_signal_monitor_metadata_list_with_http_info(self, **kwargs):
        """
        Get a list of metadata associated with signal monitors, including various properties that define their current state and behavior
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_signal_monitor_metadata_list_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] creator_ids: Filter items to only those created by the specified user IDs
        :param str name_search: Filter the items to those whose name match any part of the specified string
        :param str workbook_search: Filter the items to those whose signals are scoped to workbooks that match any part of the specified string
        :param list[str] signal_ids: Filter items to only those that are monitoring one of the specified signals as specified by the list of IDs
        :param bool enabled_filter: Filter items by their enabled status
        :param str workbook_type_filter: Filter items by the type of workbook they are scoped to
        :param int offset: The pagination offset, the number of items that will be skipped.
        :param int limit: The pagination limit, the total number of items that will be returned in this page of results
        :param str sort_by: Order the items by either name, workbook or createdAt
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: SignalMonitorMetadataOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorMetadataOutputListV1
        """

        all_params = ['creator_ids', 'name_search', 'workbook_search', 'signal_ids', 'enabled_filter', 'workbook_type_filter', 'offset', 'limit', 'sort_by', 'sort_asc']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_signal_monitor_metadata_list" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'creator_ids' in params:
            query_params.append(('creatorIds', params['creator_ids']))
            collection_formats['creatorIds'] = 'multi'
        if 'name_search' in params:
            query_params.append(('nameSearch', params['name_search']))
        if 'workbook_search' in params:
            query_params.append(('workbookSearch', params['workbook_search']))
        if 'signal_ids' in params:
            query_params.append(('signalIds', params['signal_ids']))
            collection_formats['signalIds'] = 'multi'
        if 'enabled_filter' in params:
            query_params.append(('enabledFilter', params['enabled_filter']))
        if 'workbook_type_filter' in params:
            query_params.append(('workbookTypeFilter', params['workbook_type_filter']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'sort_by' in params:
            query_params.append(('sortBy', params['sort_by']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors/metadata', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'SignalMonitorMetadataOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_signal_monitors(self, **kwargs):
        """
        Get a list of signal monitors
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_signal_monitors(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] executor_ids: Filter signal monitors to only those created by the specified user IDs
        :param str name_search: Filter the signal monitors to those whose name match any part of the specified string
        :param list[str] signal_ids: Filter signal monitors to only those that are monitoring one of the specified signals as specified by the list of IDs
        :param bool enabled_filter: Filter signal monitors by their enabled status
        :param int offset: Filters the result for Signal Monitors matching enabled == enabledFilter.
        :param int limit: The pagination limit, the total number of signal monitor that will be returned in this page of results
        :param str sort_field: Orders the signal monitors by either name, createdAt or workbook
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: GetSignalMonitorItemsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetSignalMonitorItemsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_signal_monitors_with_http_info(**kwargs)
        else:
            (data) = self.get_signal_monitors_with_http_info(**kwargs)
            return data

    def get_signal_monitors_with_http_info(self, **kwargs):
        """
        Get a list of signal monitors
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_signal_monitors_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] executor_ids: Filter signal monitors to only those created by the specified user IDs
        :param str name_search: Filter the signal monitors to those whose name match any part of the specified string
        :param list[str] signal_ids: Filter signal monitors to only those that are monitoring one of the specified signals as specified by the list of IDs
        :param bool enabled_filter: Filter signal monitors by their enabled status
        :param int offset: Filters the result for Signal Monitors matching enabled == enabledFilter.
        :param int limit: The pagination limit, the total number of signal monitor that will be returned in this page of results
        :param str sort_field: Orders the signal monitors by either name, createdAt or workbook
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: GetSignalMonitorItemsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetSignalMonitorItemsOutputV1
        """

        all_params = ['executor_ids', 'name_search', 'signal_ids', 'enabled_filter', 'offset', 'limit', 'sort_field', 'sort_asc']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_signal_monitors" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'executor_ids' in params:
            query_params.append(('executorIds', params['executor_ids']))
            collection_formats['executorIds'] = 'multi'
        if 'name_search' in params:
            query_params.append(('nameSearch', params['name_search']))
        if 'signal_ids' in params:
            query_params.append(('signalIds', params['signal_ids']))
            collection_formats['signalIds'] = 'multi'
        if 'enabled_filter' in params:
            query_params.append(('enabledFilter', params['enabled_filter']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'sort_field' in params:
            query_params.append(('sortField', params['sort_field']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'GetSignalMonitorItemsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def run_signal_monitor_job(self, **kwargs):
        """
        Triggers an immediate execution of the signal monitor job if it is not currently running. If the job is already running, run it again after current job completes.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.run_signal_monitor_job(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the signal monitor (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.run_signal_monitor_job_with_http_info(**kwargs)
        else:
            (data) = self.run_signal_monitor_job_with_http_info(**kwargs)
            return data

    def run_signal_monitor_job_with_http_info(self, **kwargs):
        """
        Triggers an immediate execution of the signal monitor job if it is not currently running. If the job is already running, run it again after current job completes.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.run_signal_monitor_job_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the signal monitor (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_signal_monitor_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `run_signal_monitor_job`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors/{id}/run', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_signal_monitor(self, **kwargs):
        """
        Update a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_signal_monitor(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SignalMonitorInputV1 body: (required)
        :param str id: The Seeq ID for the signal monitor (required)
        :return: SignalMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_signal_monitor_with_http_info(**kwargs)
        else:
            (data) = self.update_signal_monitor_with_http_info(**kwargs)
            return data

    def update_signal_monitor_with_http_info(self, **kwargs):
        """
        Update a signal monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_signal_monitor_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SignalMonitorInputV1 body: (required)
        :param str id: The Seeq ID for the signal monitor (required)
        :return: SignalMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SignalMonitorOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_signal_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_signal_monitor`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_signal_monitor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/signal-monitors/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'SignalMonitorOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConnectionStatusV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_version_required': 'str',
        'connection_message': 'str',
        'connector_developer_name': 'str',
        'connector_developer_support_url': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'id': 'str',
        'indexing_datasource_connection': 'bool',
        'name': 'str',
        'pull_datasource_connection': 'bool',
        'reinitialized': 'bool',
        'status': 'str',
        'sync_progress': 'SyncProgress',
        'sync_status': 'str',
        'version': 'str'
    }

    attribute_map = {
        'agent_version_required': 'agentVersionRequired',
        'connection_message': 'connectionMessage',
        'connector_developer_name': 'connectorDeveloperName',
        'connector_developer_support_url': 'connectorDeveloperSupportUrl',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'id': 'id',
        'indexing_datasource_connection': 'indexingDatasourceConnection',
        'name': 'name',
        'pull_datasource_connection': 'pullDatasourceConnection',
        'reinitialized': 'reinitialized',
        'status': 'status',
        'sync_progress': 'syncProgress',
        'sync_status': 'syncStatus',
        'version': 'version'
    }

    def __init__(self, agent_version_required=None, connection_message=None, connector_developer_name=None, connector_developer_support_url=None, datasource_class=None, datasource_id=None, id=None, indexing_datasource_connection=False, name=None, pull_datasource_connection=False, reinitialized=False, status=None, sync_progress=None, sync_status=None, version=None):
        """
        ConnectionStatusV1 - a model defined in Swagger
        """

        self._agent_version_required = None
        self._connection_message = None
        self._connector_developer_name = None
        self._connector_developer_support_url = None
        self._datasource_class = None
        self._datasource_id = None
        self._id = None
        self._indexing_datasource_connection = None
        self._name = None
        self._pull_datasource_connection = None
        self._reinitialized = None
        self._status = None
        self._sync_progress = None
        self._sync_status = None
        self._version = None

        if agent_version_required is not None:
          self.agent_version_required = agent_version_required
        if connection_message is not None:
          self.connection_message = connection_message
        if connector_developer_name is not None:
          self.connector_developer_name = connector_developer_name
        if connector_developer_support_url is not None:
          self.connector_developer_support_url = connector_developer_support_url
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if id is not None:
          self.id = id
        if indexing_datasource_connection is not None:
          self.indexing_datasource_connection = indexing_datasource_connection
        if name is not None:
          self.name = name
        if pull_datasource_connection is not None:
          self.pull_datasource_connection = pull_datasource_connection
        if reinitialized is not None:
          self.reinitialized = reinitialized
        if status is not None:
          self.status = status
        if sync_progress is not None:
          self.sync_progress = sync_progress
        if sync_status is not None:
          self.sync_status = sync_status
        if version is not None:
          self.version = version

    @property
    def agent_version_required(self):
        """
        Gets the agent_version_required of this ConnectionStatusV1.
        The version of the Agent required by this Connector

        :return: The agent_version_required of this ConnectionStatusV1.
        :rtype: str
        """
        return self._agent_version_required

    @agent_version_required.setter
    def agent_version_required(self, agent_version_required):
        """
        Sets the agent_version_required of this ConnectionStatusV1.
        The version of the Agent required by this Connector

        :param agent_version_required: The agent_version_required of this ConnectionStatusV1.
        :type: str
        """

        self._agent_version_required = agent_version_required

    @property
    def connection_message(self):
        """
        Gets the connection_message of this ConnectionStatusV1.
        The message indicating the status of the connection to the datasource (e.g. reason for disconnection)

        :return: The connection_message of this ConnectionStatusV1.
        :rtype: str
        """
        return self._connection_message

    @connection_message.setter
    def connection_message(self, connection_message):
        """
        Sets the connection_message of this ConnectionStatusV1.
        The message indicating the status of the connection to the datasource (e.g. reason for disconnection)

        :param connection_message: The connection_message of this ConnectionStatusV1.
        :type: str
        """

        self._connection_message = connection_message

    @property
    def connector_developer_name(self):
        """
        Gets the connector_developer_name of this ConnectionStatusV1.
        The name of this datasource's connector developer.

        :return: The connector_developer_name of this ConnectionStatusV1.
        :rtype: str
        """
        return self._connector_developer_name

    @connector_developer_name.setter
    def connector_developer_name(self, connector_developer_name):
        """
        Sets the connector_developer_name of this ConnectionStatusV1.
        The name of this datasource's connector developer.

        :param connector_developer_name: The connector_developer_name of this ConnectionStatusV1.
        :type: str
        """

        self._connector_developer_name = connector_developer_name

    @property
    def connector_developer_support_url(self):
        """
        Gets the connector_developer_support_url of this ConnectionStatusV1.
        The support URL of this datasource's connector developer.

        :return: The connector_developer_support_url of this ConnectionStatusV1.
        :rtype: str
        """
        return self._connector_developer_support_url

    @connector_developer_support_url.setter
    def connector_developer_support_url(self, connector_developer_support_url):
        """
        Sets the connector_developer_support_url of this ConnectionStatusV1.
        The support URL of this datasource's connector developer.

        :param connector_developer_support_url: The connector_developer_support_url of this ConnectionStatusV1.
        :type: str
        """

        self._connector_developer_support_url = connector_developer_support_url

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this ConnectionStatusV1.
        The datasource class served by this connector.  Example: OSIsoft PI

        :return: The datasource_class of this ConnectionStatusV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this ConnectionStatusV1.
        The datasource class served by this connector.  Example: OSIsoft PI

        :param datasource_class: The datasource_class of this ConnectionStatusV1.
        :type: str
        """
        if datasource_class is None:
            raise ValueError("Invalid value for `datasource_class`, must not be `None`")

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this ConnectionStatusV1.
        The datasource ID served by this connector.

        :return: The datasource_id of this ConnectionStatusV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this ConnectionStatusV1.
        The datasource ID served by this connector.

        :param datasource_id: The datasource_id of this ConnectionStatusV1.
        :type: str
        """
        if datasource_id is None:
            raise ValueError("Invalid value for `datasource_id`, must not be `None`")

        self._datasource_id = datasource_id

    @property
    def id(self):
        """
        Gets the id of this ConnectionStatusV1.
        The ID of the connector. This ID uniquely identifies this connector but does not convey any information about the connector. There is no specified structure for this ID; it may be in UUID form but need not be

        :return: The id of this ConnectionStatusV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConnectionStatusV1.
        The ID of the connector. This ID uniquely identifies this connector but does not convey any information about the connector. There is no specified structure for this ID; it may be in UUID form but need not be

        :param id: The id of this ConnectionStatusV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def indexing_datasource_connection(self):
        """
        Gets the indexing_datasource_connection of this ConnectionStatusV1.
        Indicates whether the datasource allows metadata indexing.

        :return: The indexing_datasource_connection of this ConnectionStatusV1.
        :rtype: bool
        """
        return self._indexing_datasource_connection

    @indexing_datasource_connection.setter
    def indexing_datasource_connection(self, indexing_datasource_connection):
        """
        Sets the indexing_datasource_connection of this ConnectionStatusV1.
        Indicates whether the datasource allows metadata indexing.

        :param indexing_datasource_connection: The indexing_datasource_connection of this ConnectionStatusV1.
        :type: bool
        """
        if indexing_datasource_connection is None:
            raise ValueError("Invalid value for `indexing_datasource_connection`, must not be `None`")

        self._indexing_datasource_connection = indexing_datasource_connection

    @property
    def name(self):
        """
        Gets the name of this ConnectionStatusV1.
        The name of this connection. The name should represent the specific data source to which this connection connects.  Example: AMAZONA-4RV912N

        :return: The name of this ConnectionStatusV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConnectionStatusV1.
        The name of this connection. The name should represent the specific data source to which this connection connects.  Example: AMAZONA-4RV912N

        :param name: The name of this ConnectionStatusV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def pull_datasource_connection(self):
        """
        Gets the pull_datasource_connection of this ConnectionStatusV1.
        Indicates whether the datasource allows pull requests.

        :return: The pull_datasource_connection of this ConnectionStatusV1.
        :rtype: bool
        """
        return self._pull_datasource_connection

    @pull_datasource_connection.setter
    def pull_datasource_connection(self, pull_datasource_connection):
        """
        Sets the pull_datasource_connection of this ConnectionStatusV1.
        Indicates whether the datasource allows pull requests.

        :param pull_datasource_connection: The pull_datasource_connection of this ConnectionStatusV1.
        :type: bool
        """
        if pull_datasource_connection is None:
            raise ValueError("Invalid value for `pull_datasource_connection`, must not be `None`")

        self._pull_datasource_connection = pull_datasource_connection

    @property
    def reinitialized(self):
        """
        Gets the reinitialized of this ConnectionStatusV1.
        Indicates whether the connection was reinitialized.

        :return: The reinitialized of this ConnectionStatusV1.
        :rtype: bool
        """
        return self._reinitialized

    @reinitialized.setter
    def reinitialized(self, reinitialized):
        """
        Sets the reinitialized of this ConnectionStatusV1.
        Indicates whether the connection was reinitialized.

        :param reinitialized: The reinitialized of this ConnectionStatusV1.
        :type: bool
        """
        if reinitialized is None:
            raise ValueError("Invalid value for `reinitialized`, must not be `None`")

        self._reinitialized = reinitialized

    @property
    def status(self):
        """
        Gets the status of this ConnectionStatusV1.
        The status of the current connection between the datasource and this connector. Valid values are Connected, Disconnected and Connecting. If the state is Disconnected (or Connecting), it could be caused by a failure in the connection between the connector and its datasource or a failed connection between the Seeq application server and the agent hosting this connector. See connectionMessage.

        :return: The status of this ConnectionStatusV1.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ConnectionStatusV1.
        The status of the current connection between the datasource and this connector. Valid values are Connected, Disconnected and Connecting. If the state is Disconnected (or Connecting), it could be caused by a failure in the connection between the connector and its datasource or a failed connection between the Seeq application server and the agent hosting this connector. See connectionMessage.

        :param status: The status of this ConnectionStatusV1.
        :type: str
        """

        self._status = status

    @property
    def sync_progress(self):
        """
        Gets the sync_progress of this ConnectionStatusV1.

        :return: The sync_progress of this ConnectionStatusV1.
        :rtype: SyncProgress
        """
        return self._sync_progress

    @sync_progress.setter
    def sync_progress(self, sync_progress):
        """
        Sets the sync_progress of this ConnectionStatusV1.

        :param sync_progress: The sync_progress of this ConnectionStatusV1.
        :type: SyncProgress
        """

        self._sync_progress = sync_progress

    @property
    def sync_status(self):
        """
        Gets the sync_status of this ConnectionStatusV1.
        The synchronization status of the current connection between the datasource and this connector. Valid values are SYNC_UNKNOWN, SYNC_INITIALIZING, SYNC_IN_PROGRESS, SYNC_COMPLETE, SYNC_ARCHIVING_DELETED_ITEMS

        :return: The sync_status of this ConnectionStatusV1.
        :rtype: str
        """
        return self._sync_status

    @sync_status.setter
    def sync_status(self, sync_status):
        """
        Sets the sync_status of this ConnectionStatusV1.
        The synchronization status of the current connection between the datasource and this connector. Valid values are SYNC_UNKNOWN, SYNC_INITIALIZING, SYNC_IN_PROGRESS, SYNC_COMPLETE, SYNC_ARCHIVING_DELETED_ITEMS

        :param sync_status: The sync_status of this ConnectionStatusV1.
        :type: str
        """

        self._sync_status = sync_status

    @property
    def version(self):
        """
        Gets the version of this ConnectionStatusV1.
        The version of the Connector

        :return: The version of this ConnectionStatusV1.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ConnectionStatusV1.
        The version of the Connector

        :param version: The version of this ConnectionStatusV1.
        :type: str
        """

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConnectionStatusV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionCSVUpdateInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_delimiter: str
    _header_row: int
    _name: str
    _upload_filename: str


    def __init__(
        self,
        column_delimiter: Optional[str] = None,
        header_row: Optional[int] = None,
        name: Optional[str] = None,
        upload_filename: Optional[str] = None,
    ) -> None: ...

    @property
    def column_delimiter(self) -> str: ...

    @column_delimiter.setter
    def column_delimiter(self, column_delimiter: str) -> None: ...

    @property
    def header_row(self) -> int: ...

    @header_row.setter
    def header_row(self, header_row: int) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def upload_filename(self) -> str: ...

    @upload_filename.setter
    def upload_filename(self, upload_filename: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourceStatusV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _datasource_class: Optional[str]
    _datasource_guid: Optional[str]
    _datasource_id: Optional[str]
    _datasource_name: Optional[str]
    _enabled: Optional[bool]
    _seeq_internal: Optional[bool]
    _statistics: Optional[DatasourceStatisticsV1]
    _stored_in_seeq: Optional[bool]


    def __init__(
        self,
        datasource_class: Optional[str] = None,
        datasource_guid: Optional[str] = None,
        datasource_id: Optional[str] = None,
        datasource_name: Optional[str] = None,
        enabled: Optional[bool] = False,
        seeq_internal: Optional[bool] = False,
        statistics: Optional[DatasourceStatisticsV1] = None,
        stored_in_seeq: Optional[bool] = False,
    ) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_guid(self) -> Optional[str]: ...

    @datasource_guid.setter
    def datasource_guid(self, datasource_guid: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def datasource_name(self) -> Optional[str]: ...

    @datasource_name.setter
    def datasource_name(self, datasource_name: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def seeq_internal(self) -> Optional[bool]: ...

    @seeq_internal.setter
    def seeq_internal(self, seeq_internal: Optional[bool]) -> None: ...

    @property
    def statistics(self) -> Optional[DatasourceStatisticsV1]: ...

    @statistics.setter
    def statistics(self, statistics: Optional[DatasourceStatisticsV1]) -> None: ...

    @property
    def stored_in_seeq(self) -> Optional[bool]: ...

    @stored_in_seeq.setter
    def stored_in_seeq(self, stored_in_seeq: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaRunInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _continuation_token: Optional[str]
    _end: Optional[str]
    _formula: str
    _fragments: Optional[List[str]]
    _function: Optional[str]
    _items_to_scale_across: Optional[List[str]]
    _limit: Optional[int]
    _parameters: List[str]
    _reduce_formula: Optional[str]
    _root: Optional[str]
    _start: Optional[str]
    _time_format: Optional[str]


    def __init__(
        self,
        continuation_token: Optional[str] = None,
        end: Optional[str] = None,
        formula: Optional[str] = None,
        fragments: Optional[List[str]] = None,
        function: Optional[str] = None,
        items_to_scale_across: Optional[List[str]] = None,
        limit: Optional[int] = None,
        parameters: Optional[List[str]] = None,
        reduce_formula: Optional[str] = None,
        root: Optional[str] = None,
        start: Optional[str] = None,
        time_format: Optional[str] = None,
    ) -> None: ...

    @property
    def continuation_token(self) -> Optional[str]: ...

    @continuation_token.setter
    def continuation_token(self, continuation_token: Optional[str]) -> None: ...

    @property
    def end(self) -> Optional[str]: ...

    @end.setter
    def end(self, end: Optional[str]) -> None: ...

    @property
    def formula(self) -> str: ...

    @formula.setter
    def formula(self, formula: str) -> None: ...

    @property
    def fragments(self) -> Optional[List[str]]: ...

    @fragments.setter
    def fragments(self, fragments: Optional[List[str]]) -> None: ...

    @property
    def function(self) -> Optional[str]: ...

    @function.setter
    def function(self, function: Optional[str]) -> None: ...

    @property
    def items_to_scale_across(self) -> Optional[List[str]]: ...

    @items_to_scale_across.setter
    def items_to_scale_across(self, items_to_scale_across: Optional[List[str]]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def parameters(self) -> List[str]: ...

    @parameters.setter
    def parameters(self, parameters: List[str]) -> None: ...

    @property
    def reduce_formula(self) -> Optional[str]: ...

    @reduce_formula.setter
    def reduce_formula(self, reduce_formula: Optional[str]) -> None: ...

    @property
    def root(self) -> Optional[str]: ...

    @root.setter
    def root(self, root: Optional[str]) -> None: ...

    @property
    def start(self) -> Optional[str]: ...

    @start.setter
    def start(self, start: Optional[str]) -> None: ...

    @property
    def time_format(self) -> Optional[str]: ...

    @time_format.setter
    def time_format(self, time_format: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CommentCategoryOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: Optional[str]
    _creator_id: Optional[str]
    _help_text: Optional[str]
    _icon: Optional[str]
    _id: Optional[str]
    _name: Optional[str]
    _title: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        created_at: Optional[str] = None,
        creator_id: Optional[str] = None,
        help_text: Optional[str] = None,
        icon: Optional[str] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        title: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator_id(self) -> Optional[str]: ...

    @creator_id.setter
    def creator_id(self, creator_id: Optional[str]) -> None: ...

    @property
    def help_text(self) -> Optional[str]: ...

    @help_text.setter
    def help_text(self, help_text: Optional[str]) -> None: ...

    @property
    def icon(self) -> Optional[str]: ...

    @icon.setter
    def icon(self, icon: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def title(self) -> Optional[str]: ...

    @title.setter
    def title(self, title: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourcesStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_orchestrators: Optional[List[AgentOrchestratorOutputV1]]
    _agents: Optional[List[AgentStatusOutputV1]]
    _connected_connections_count: int
    _connected_datasources_count: int
    _datasources: Optional[List[DatasourceSummaryStatusOutputV1]]
    _total_connections_count: int
    _total_datasources_count: int


    def __init__(
        self,
        agent_orchestrators: Optional[List[AgentOrchestratorOutputV1]] = None,
        agents: Optional[List[AgentStatusOutputV1]] = None,
        connected_connections_count: Optional[int] = None,
        connected_datasources_count: Optional[int] = None,
        datasources: Optional[List[DatasourceSummaryStatusOutputV1]] = None,
        total_connections_count: Optional[int] = None,
        total_datasources_count: Optional[int] = None,
    ) -> None: ...

    @property
    def agent_orchestrators(self) -> Optional[List[AgentOrchestratorOutputV1]]: ...

    @agent_orchestrators.setter
    def agent_orchestrators(self, agent_orchestrators: Optional[List[AgentOrchestratorOutputV1]]) -> None: ...

    @property
    def agents(self) -> Optional[List[AgentStatusOutputV1]]: ...

    @agents.setter
    def agents(self, agents: Optional[List[AgentStatusOutputV1]]) -> None: ...

    @property
    def connected_connections_count(self) -> int: ...

    @connected_connections_count.setter
    def connected_connections_count(self, connected_connections_count: int) -> None: ...

    @property
    def connected_datasources_count(self) -> int: ...

    @connected_datasources_count.setter
    def connected_datasources_count(self, connected_datasources_count: int) -> None: ...

    @property
    def datasources(self) -> Optional[List[DatasourceSummaryStatusOutputV1]]: ...

    @datasources.setter
    def datasources(self, datasources: Optional[List[DatasourceSummaryStatusOutputV1]]) -> None: ...

    @property
    def total_connections_count(self) -> int: ...

    @total_connections_count.setter
    def total_connections_count(self, total_connections_count: int) -> None: ...

    @property
    def total_datasources_count(self) -> int: ...

    @total_datasources_count.setter
    def total_datasources_count(self, total_datasources_count: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LicenseStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_features: Optional[List[LicensedFeatureStatusOutputV1]]
    _company_name: Optional[str]
    _configuration: Optional[Dict[str, Any]]
    _contract_number: Optional[str]
    _days_to_expiration: Optional[int]
    _hostname: Optional[str]
    _level: Optional[str]
    _user_count: Optional[int]
    _user_limit_restrict: Optional[int]
    _user_limit_warn: Optional[int]
    _valid_through: Optional[str]
    _validity: Optional[str]


    def __init__(
        self,
        additional_features: Optional[List[LicensedFeatureStatusOutputV1]] = None,
        company_name: Optional[str] = None,
        configuration: Optional[Dict[str, Any]] = None,
        contract_number: Optional[str] = None,
        days_to_expiration: Optional[int] = None,
        hostname: Optional[str] = None,
        level: Optional[str] = None,
        user_count: Optional[int] = None,
        user_limit_restrict: Optional[int] = None,
        user_limit_warn: Optional[int] = None,
        valid_through: Optional[str] = None,
        validity: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_features(self) -> Optional[List[LicensedFeatureStatusOutputV1]]: ...

    @additional_features.setter
    def additional_features(self, additional_features: Optional[List[LicensedFeatureStatusOutputV1]]) -> None: ...

    @property
    def company_name(self) -> Optional[str]: ...

    @company_name.setter
    def company_name(self, company_name: Optional[str]) -> None: ...

    @property
    def configuration(self) -> Optional[Dict[str, Any]]: ...

    @configuration.setter
    def configuration(self, configuration: Optional[Dict[str, Any]]) -> None: ...

    @property
    def contract_number(self) -> Optional[str]: ...

    @contract_number.setter
    def contract_number(self, contract_number: Optional[str]) -> None: ...

    @property
    def days_to_expiration(self) -> Optional[int]: ...

    @days_to_expiration.setter
    def days_to_expiration(self, days_to_expiration: Optional[int]) -> None: ...

    @property
    def hostname(self) -> Optional[str]: ...

    @hostname.setter
    def hostname(self, hostname: Optional[str]) -> None: ...

    @property
    def level(self) -> Optional[str]: ...

    @level.setter
    def level(self, level: Optional[str]) -> None: ...

    @property
    def user_count(self) -> Optional[int]: ...

    @user_count.setter
    def user_count(self, user_count: Optional[int]) -> None: ...

    @property
    def user_limit_restrict(self) -> Optional[int]: ...

    @user_limit_restrict.setter
    def user_limit_restrict(self, user_limit_restrict: Optional[int]) -> None: ...

    @property
    def user_limit_warn(self) -> Optional[int]: ...

    @user_limit_warn.setter
    def user_limit_warn(self, user_limit_warn: Optional[int]) -> None: ...

    @property
    def valid_through(self) -> Optional[str]: ...

    @valid_through.setter
    def valid_through(self, valid_through: Optional[str]) -> None: ...

    @property
    def validity(self) -> Optional[str]: ...

    @validity.setter
    def validity(self, validity: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DerivedFeatureV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'id': 'str',
        'is_output': 'bool',
        'name': 'str',
        'output_type': 'str',
        'rules': 'list[FeatureRuleV1]'
    }

    attribute_map = {
        'description': 'description',
        'id': 'id',
        'is_output': 'isOutput',
        'name': 'name',
        'output_type': 'outputType',
        'rules': 'rules'
    }

    def __init__(self, description=None, id=None, is_output=None, name=None, output_type=None, rules=None):
        """
        DerivedFeatureV1 - a model defined in Swagger
        """

        self._description = None
        self._id = None
        self._is_output = None
        self._name = None
        self._output_type = None
        self._rules = None

        if description is not None:
          self.description = description
        if id is not None:
          self.id = id
        if is_output is not None:
          self.is_output = is_output
        if name is not None:
          self.name = name
        if output_type is not None:
          self.output_type = output_type
        if rules is not None:
          self.rules = rules

    @property
    def description(self):
        """
        Gets the description of this DerivedFeatureV1.
        Description of the feature

        :return: The description of this DerivedFeatureV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DerivedFeatureV1.
        Description of the feature

        :param description: The description of this DerivedFeatureV1.
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """
        Gets the id of this DerivedFeatureV1.
        Feature ID; omit on create

        :return: The id of this DerivedFeatureV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DerivedFeatureV1.
        Feature ID; omit on create

        :param id: The id of this DerivedFeatureV1.
        :type: str
        """

        self._id = id

    @property
    def is_output(self):
        """
        Gets the is_output of this DerivedFeatureV1.
        Indicates if this feature is an output

        :return: The is_output of this DerivedFeatureV1.
        :rtype: bool
        """
        return self._is_output

    @is_output.setter
    def is_output(self, is_output):
        """
        Sets the is_output of this DerivedFeatureV1.
        Indicates if this feature is an output

        :param is_output: The is_output of this DerivedFeatureV1.
        :type: bool
        """

        self._is_output = is_output

    @property
    def name(self):
        """
        Gets the name of this DerivedFeatureV1.
        Name of the feature

        :return: The name of this DerivedFeatureV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DerivedFeatureV1.
        Name of the feature

        :param name: The name of this DerivedFeatureV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def output_type(self):
        """
        Gets the output_type of this DerivedFeatureV1.
        Type of the feature output

        :return: The output_type of this DerivedFeatureV1.
        :rtype: str
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        """
        Sets the output_type of this DerivedFeatureV1.
        Type of the feature output

        :param output_type: The output_type of this DerivedFeatureV1.
        :type: str
        """
        if output_type is None:
            raise ValueError("Invalid value for `output_type`, must not be `None`")

        self._output_type = output_type

    @property
    def rules(self):
        """
        Gets the rules of this DerivedFeatureV1.
        The list of rules that determine the resulting value of a feature. At least one rule is required

        :return: The rules of this DerivedFeatureV1.
        :rtype: list[FeatureRuleV1]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this DerivedFeatureV1.
        The list of rules that determine the resulting value of a feature. At least one rule is required

        :param rules: The rules of this DerivedFeatureV1.
        :type: list[FeatureRuleV1]
        """
        if rules is None:
            raise ValueError("Invalid value for `rules`, must not be `None`")

        self._rules = rules

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DerivedFeatureV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DirectItemIdsSourceV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_id': 'str',
        'condition_stats': 'list[ConditionTableStatInputForDirectItemsV1]',
        'item_ids': 'list[str]'
    }

    attribute_map = {
        'asset_id': 'assetId',
        'condition_stats': 'conditionStats',
        'item_ids': 'itemIds'
    }

    def __init__(self, asset_id=None, condition_stats=None, item_ids=None):
        """
        DirectItemIdsSourceV1 - a model defined in Swagger
        """

        self._asset_id = None
        self._condition_stats = None
        self._item_ids = None

        if asset_id is not None:
          self.asset_id = asset_id
        if condition_stats is not None:
          self.condition_stats = condition_stats
        if item_ids is not None:
          self.item_ids = item_ids

    @property
    def asset_id(self):
        """
        Gets the asset_id of this DirectItemIdsSourceV1.
        Optional root asset ID to run conditions across its children

        :return: The asset_id of this DirectItemIdsSourceV1.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """
        Sets the asset_id of this DirectItemIdsSourceV1.
        Optional root asset ID to run conditions across its children

        :param asset_id: The asset_id of this DirectItemIdsSourceV1.
        :type: str
        """

        self._asset_id = asset_id

    @property
    def condition_stats(self):
        """
        Gets the condition_stats of this DirectItemIdsSourceV1.
        The list of statistics to calculate for the condition items

        :return: The condition_stats of this DirectItemIdsSourceV1.
        :rtype: list[ConditionTableStatInputForDirectItemsV1]
        """
        return self._condition_stats

    @condition_stats.setter
    def condition_stats(self, condition_stats):
        """
        Sets the condition_stats of this DirectItemIdsSourceV1.
        The list of statistics to calculate for the condition items

        :param condition_stats: The condition_stats of this DirectItemIdsSourceV1.
        :type: list[ConditionTableStatInputForDirectItemsV1]
        """

        self._condition_stats = condition_stats

    @property
    def item_ids(self):
        """
        Gets the item_ids of this DirectItemIdsSourceV1.
        List of condition and condition metric item IDs to run the table across

        :return: The item_ids of this DirectItemIdsSourceV1.
        :rtype: list[str]
        """
        return self._item_ids

    @item_ids.setter
    def item_ids(self, item_ids):
        """
        Sets the item_ids of this DirectItemIdsSourceV1.
        List of condition and condition metric item IDs to run the table across

        :param item_ids: The item_ids of this DirectItemIdsSourceV1.
        :type: list[str]
        """
        if item_ids is None:
            raise ValueError("Invalid value for `item_ids`, must not be `None`")

        self._item_ids = item_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DirectItemIdsSourceV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonMetricOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'baseline_value': 'float',
        'column': 'str',
        'current_value': 'float',
        'delta': 'float',
        'metric': 'str',
        'percent_change': 'float'
    }

    attribute_map = {
        'baseline_value': 'baselineValue',
        'column': 'column',
        'current_value': 'currentValue',
        'delta': 'delta',
        'metric': 'metric',
        'percent_change': 'percentChange'
    }

    def __init__(self, baseline_value=None, column=None, current_value=None, delta=None, metric=None, percent_change=None):
        """
        BoardTimeframeComparisonMetricOutputV1 - a model defined in Swagger
        """

        self._baseline_value = None
        self._column = None
        self._current_value = None
        self._delta = None
        self._metric = None
        self._percent_change = None

        if baseline_value is not None:
          self.baseline_value = baseline_value
        if column is not None:
          self.column = column
        if current_value is not None:
          self.current_value = current_value
        if delta is not None:
          self.delta = delta
        if metric is not None:
          self.metric = metric
        if percent_change is not None:
          self.percent_change = percent_change

    @property
    def baseline_value(self):
        """
        Gets the baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        Baseline value for the metric

        :return: The baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._baseline_value

    @baseline_value.setter
    def baseline_value(self, baseline_value):
        """
        Sets the baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        Baseline value for the metric

        :param baseline_value: The baseline_value of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._baseline_value = baseline_value

    @property
    def column(self):
        """
        Gets the column of this BoardTimeframeComparisonMetricOutputV1.
        Column name being compared

        :return: The column of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: str
        """
        return self._column

    @column.setter
    def column(self, column):
        """
        Sets the column of this BoardTimeframeComparisonMetricOutputV1.
        Column name being compared

        :param column: The column of this BoardTimeframeComparisonMetricOutputV1.
        :type: str
        """
        if column is None:
            raise ValueError("Invalid value for `column`, must not be `None`")

        self._column = column

    @property
    def current_value(self):
        """
        Gets the current_value of this BoardTimeframeComparisonMetricOutputV1.
        Current value for the metric

        :return: The current_value of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._current_value

    @current_value.setter
    def current_value(self, current_value):
        """
        Sets the current_value of this BoardTimeframeComparisonMetricOutputV1.
        Current value for the metric

        :param current_value: The current_value of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._current_value = current_value

    @property
    def delta(self):
        """
        Gets the delta of this BoardTimeframeComparisonMetricOutputV1.
        Delta between current and baseline

        :return: The delta of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._delta

    @delta.setter
    def delta(self, delta):
        """
        Sets the delta of this BoardTimeframeComparisonMetricOutputV1.
        Delta between current and baseline

        :param delta: The delta of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._delta = delta

    @property
    def metric(self):
        """
        Gets the metric of this BoardTimeframeComparisonMetricOutputV1.
        Metric used for comparison (mean|sum|min|max)

        :return: The metric of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this BoardTimeframeComparisonMetricOutputV1.
        Metric used for comparison (mean|sum|min|max)

        :param metric: The metric of this BoardTimeframeComparisonMetricOutputV1.
        :type: str
        """
        if metric is None:
            raise ValueError("Invalid value for `metric`, must not be `None`")

        self._metric = metric

    @property
    def percent_change(self):
        """
        Gets the percent_change of this BoardTimeframeComparisonMetricOutputV1.
        Percent change from baseline (null if baseline is zero)

        :return: The percent_change of this BoardTimeframeComparisonMetricOutputV1.
        :rtype: float
        """
        return self._percent_change

    @percent_change.setter
    def percent_change(self, percent_change):
        """
        Sets the percent_change of this BoardTimeframeComparisonMetricOutputV1.
        Percent change from baseline (null if baseline is zero)

        :param percent_change: The percent_change of this BoardTimeframeComparisonMetricOutputV1.
        :type: float
        """

        self._percent_change = percent_change

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonMetricOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
